#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-lDosVvWrl88v4DrXGfX3x
key:                  pantry-0.8.3-lDosVvWrl88v4DrXGfX3x
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  d33f3428d8b6b6cfa5e16a476fe1c597
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-lDosVvWrl88v4DrXGfX3x
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    ansi-terminal-1.1-BaaOJBYZHtd1MproObBlcZ base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-JRVliUQCgig8p2H4jjVY8y
    casa-types-0.0.3-B7dltl9BQBn4l8QqKtLw4U
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV
    conduit-extra-1.3.8-6O6CtrkaMBHHbx4pVlP0Hf containers-0.6.7
    crypton-1.0.4-1xkEEzzipS99cinEMvqUU
    crypton-conduit-0.2.3-GldtDWTb9db8DJdSINmLD8
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-DB3UOaG7qXI5VF3IgGsPLx
    generic-deriving-1.14.7-J0TZoWp8KsQFzSmICi7RYK
    hackage-security-0.6.3.2-Hcr4X0rQBRlJftIyf8YsoL
    hpack-0.38.0-32RRkGtHrZJKP69TMnh1RV
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-client-tls-0.3.6.4-BD4TqKfIzwr11ySZlgGnkK
    http-conduit-2.3.9.1-5Jfl4K985Op1AUK3YAkGuJ
    http-download-0.2.1.0-Cxp7PMsjA4L6kEb8O2zpn3
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-JJwr3105NpI16YFQY3IIVN
    path-0.9.6-DliTy2WqQQpEQ9MVzd7Gxw
    path-io-1.8.2-GUPplYBqDnTBcD4VBrLKdW
    persistent-2.14.5.2-vRswv1IPIB2LskvgVvYe5
    persistent-sqlite-2.13.2.0-6KbxuTi2sPeI7LZo44hE75
    primitive-0.9.1.0-Dm8O45wtcqd5eoiJyOalCK
    resourcet-1.2.6-LJgXHkWLt2tDuo3wpypfir
    rio-0.1.24.0-FOy6ZwlWq6MH6dQTDgjnCZ
    rio-orphans-0.1.2.0-JdNEZ66REQR3o913SmT8Pq
    rio-prettyprint-0.1.8.0-Ao0bxRTcFlu1Gc1HyxlW9N
    tar-conduit-0.4.1-F7Jrzk9vt1OKzkYwyuSxFX text-2.0.2
    text-metrics-0.3.3-GKJCraGdxnuX98mdV3EI8 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BZMXqomGfYu4rulQDFCFZv
    unliftio-0.2.25.1-2ijZcbxfdeVCmMwCRtThrP
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY
    yaml-0.11.11.2-KqhXgUc3VA7C1IL3BQ5ruQ
    zip-archive-0.4.3.2-ENhLoLWDQduFhnorc0VaFP

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

